@@ -135,13 +135,13 @@ class SubscriptionRoot:
         async for data in self.client.subscribe(('subscription{environmentUpdated(%s){id}}' % (id_arg)).replace('()', '')):
             yield Environment(self.client, data["environmentUpdated"]["id"])
 
-    async def valueUpdated(self, thingId=None, id=None, hidden=None):
+    async def variableUpdated(self, thingId=None, id=None, hidden=None):
         thingId_arg = parse_arg("thingId", thingId)
         id_arg = parse_arg("id", id)
         hidden_arg = parse_arg("hidden", hidden)
 
-        async for data in self.client.subscribe(('subscription{valueUpdated(%s%s%s){id __typename}}' % (thingId_arg, id_arg, hidden_arg)).replace('()', '')):
-            yield Value(self.client, data["valueUpdated"]["id"], data["valueUpdated"]["__typename"])
+        async for data in self.client.subscribe(('subscription{variableUpdated(%s%s%s){id __typename}}' % (thingId_arg, id_arg, hidden_arg)).replace('()', '')):
+            yield Value(self.client, data["variableUpdated"]["id"], data["variableUpdated"]["__typename"])
 
     async def floatSeriesNodeUpdated(self, seriesId=None, id=None):
         seriesId_arg = parse_arg("seriesId", seriesId)
